differentialGeneTest: Tests each gene for differential expression as a function of progress through a biological process, or according to other covariates as specified.
Description
Tests each gene for differential expression as a function of progress through a biological process, or according to other covariates as specified.
Usage
differentialGeneTest(cds, fullModelFormulaStr = "expression~sm.ns(Pseudotime, df=3)", reducedModelFormulaStr = "expression~1", cores = 1)
Arguments
cds
a CellDataSet object upon which to perform this operation
fullModelFormulaStr
a formula string specifying the full model in differential expression tests (i.e. likelihood ratio tests) for each gene/feature.
reducedModelFormulaStr
a formula string specifying the reduced model in differential expression tests (i.e. likelihood ratio tests) for each gene/feature.
cores
the number of cores to be used while testing each gene for differential expression
Value
a data frame containing the p values and q-values from the likelihood ratio tests on the parallel arrays of models.