Learn R Programming

monocle (version 1.6.0)

reduceDimension: Computes a projection of a CellDataSet object into a lower dimensional space

Description

Computes a projection of a CellDataSet object into a lower dimensional space

Usage

reduceDimension(cds, max_components = 2, use_irlba = TRUE, pseudo_expr = 1, batch = NULL, covariates = NULL, ...)

Arguments

cds
the CellDataSet upon which to perform this operation
max_components
the dimensionality of the reduced space
use_irlba
Whether to use the IRLBA package for ICA reduction.
pseudo_expr
amount to increase expression values before dimensionality reduction
batch
a vector of labels specifying batch for each cell, the effects of which will be removed prior to dimensionality reduction.
covariates
a numeric vector or matrix specifying continuous effects to be removed prior to dimensionality reduction
...
additional arguments to pass to the dimensionality reduction function

Value

an updated CellDataSet object

Details

Currently, Monocle supports dimensionality reduction with Independent Component Analysis (ICA).