Learn R Programming

monocle (version 1.6.0)

reducedDimS: Retrieves the coordinates of each cell in the reduced-dimensionality space generated by calls to reduceDimension.

Description

Reducing the dimensionality of the expression data is a core step in the Monocle workflow. After you call reduceDimension(), this function will return the new coordinates of your cells in the reduced space.

Usage

reducedDimS(cds)

Arguments

cds
A CellDataSet object.

Value

A matrix, where rows are cell coordinates and columns correspond to dimensions of the reduced space.

Examples

Run this code
## Not run: 
# data(HSMM)
# S <- reducedDimS(HSMM)
# ## End(Not run)

Run the code above in your browser using DataLab