CellDataSet: The CellDataSet class
Description
The main class used by Monocle to hold single cell expression data. CellDataSet extends the basic Bioconductor ExpressionSet class.
Slots
reducedDimS:- Matrix of class
"numeric", containing the source values computed by Independent Components Analysis. reducedDimW:- Matrix of class
"numeric", containing the whitened expression values computed during Independent Components Analysis. reducedDimA:- Matrix of class
"numeric", containing the weight values computed by Independent Components Analysis. minSpanningTree:- Object of class
"igraph", containing the minimum spanning tree used by Monocle to order cells according to progress through a biological process. cellPairwiseDistances:- Matrix of class
"numeric", containing the pairwise distances between cells in the reduced dimension space. expressionFamily:- Object of class
"vglmff", specifying the VGAM family function used for expression responses. lowerDetectionLimit:- A
"numeric" value specifying the minimum expression level considered to be true expression.
Details
This class is initialized from a matrix of expression values Methods that operate on CellDataSet objects constitute the basic Monocle workflow.